# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#            ENIGMA-MDD subfields analysis script
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# This script performs all necessary analyses for the ENIGMA-MDD
# subfields project. It is based on the cortical analysis script
# of ENIGMA-MDD (version 'MDD_regressions_1_March16.R').
# Modified by P. G. Sämann, based on the version by L. Schmaal
# and D. P. Hibar
# Input files needed are: hippo_subfields.csv, Covariates.csv
# R libraries needed: 'ppcor'
#
# Written for the ENIGMA MDD Working Group December 2016
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# Activate library
library("ppcor")

# USER AREA ===============================================================
whole = "eTIV"			# or Brain or TotalGM instead eTIV
AgeSq_and_interactions = 1 	# 1 for age^2 and age[^2]-by-gender terms
write_logfile = 1      	 	# 0 for output in R console; 1 for logfile
# END USER AREA ===========================================================

setwd("C:/Users/saemann/Desktop/SUBFIELDS_METAANALYSIS/sub_R_QTIM/debug/Site1_0_age")

# General preparations
fsfile <- "hippo_subfields.csv"
complete_flag <- "complete" # to exclude incomplete cases
filetype <- "subfields_complete"
rightmargin <- 1 # omit N dependent variables
globvarname = paste0('_ctl',whole)
if (AgeSq_and_interactions){globvarname = paste0('_fullmodel',globvarname)}
whole = paste(' + ', whole)
if (AgeSq_and_interactions){whole = paste0(whole,' + Age2 + factor(Sex):Age + factor(Sex):Age2')}

# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#               Create log file
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (write_logfile){
   name_logfile = "Subfield_analysis_v1.6.log"
   messages=file(name_logfile, open="wt")
   sink(messages, type="message")
   sink(messages, type="output")
}

# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#          Read in main file 
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cat('Working on subanalyses Set #1.\n')
Cort <- read.csv(fsfile); # Read in the phenotype file

# Check if all necessary columns are present

CortCols=c("SubjID","L_Hippocampal_tail","L_subiculum","L_CA1","L_hippocampal.fissure","L_presubiculum","L_parasubiculum","L_molecular_layer_HP","L_GC.ML.DG","L_CA3","L_CA4","L_fimbria","L_HATA","L_Whole_hippocampus","R_Hippocampal_tail","R_subiculum","R_CA1","R_hippocampal.fissure","R_presubiculum","R_parasubiculum","R_molecular_layer_HP","R_GC.ML.DG","R_CA3","R_CA4","R_fimbria","R_HATA","R_Whole_hippocampus","Lhippo","Rhippo","eTIV","Brain","TotalGM")

	cortcolind=match(CortCols,names(Cort))
	if(length(which(is.na(cortcolind))) > 0){
		stop('At least one of the required columns in your ', fsfile, ' file is missing. Make sure that the column names are spelled exactly as listed in the protocol\n')
	}

if(complete_flag == "complete"){
	Cort = Cort[complete.cases(Cort),]
}

# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#            Calculate mean values
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

meanCort=NULL

# Calculate means

for(x in 2:14){
	meanCort = c(meanCort, ((Cort[,x] + Cort[x+13])/2))
}

meanCort = c(meanCort, ((Cort[,28] + Cort[29])/2)) # L+R recon-all volumes

names(meanCort) = c("M_Hippocampal_tail","M_subiculum","M_CA1","M_hippocampal.fissure","M_presubiculum","M_parasubiculum","M_molecular_layer_HP","M_GC.ML.DG","M_CA3","M_CA4","M_fimbria","M_HATA","M_Whole_hippocampus","M_Hippo")
meanCort=as.data.frame(meanCort)

# Combine Cort file with the newly calculated means
# Note that eTIV, Brain and TotalGM are sorted to the end.
Cort = cbind(Cort[1:29], meanCort, Cort[31:32], Cort[30])


# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#            Check for double IDs
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# Check for duplicated SubjIDs that may cause issues with merging data sets.

if(anyDuplicated(Cort[,c("SubjID")]) != 0) { stop(paste0('You have duplicate SubjIDs in your ', fsfile, 'file.\nMake sure there are no repeat SubjIDs.\n')) }

Covs <- read.csv("Covariates.csv"); # Read in the covariates file

# Check for duplicated SubjIDs that may cause issues with merging data sets.
if(anyDuplicated(Covs[,c("SubjID")]) != 0) { stop('You have duplicate SubjIDs in your Covariates.csv file.\nMake sure there are no repeat SubjIDs.') }
	
# Check that all of the required columns are present
mcols=c("SubjID","Dx","Age","Sex","Recur","AD","Rem","AO","Sev","BDI","HDRS","Epi","ADcur")
colind=match(mcols,names(Covs))
if(length(which(is.na(colind))) > 0){
	stop('At least one of the required columns in your Covariates.csv file is missing. Make sure that the column names are spelled exactly as listed:\nIt is possible that the problem column(s) is: ', mcols[which(is.na(colind))])
}

# Add squared age term here
Covs$Age2 = Covs$Age * Covs$Age
n.covs <- ncol(Covs) - 1; # Total number of covariates, -1 removes the SubjectID column
n.sites <- n.covs - 13; # Find the number of site variables, subtract for Dx, Age, Sex from n.covs

# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# Combine the files into one dataframe
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

merged_ordered = merge(Covs, Cort, by="SubjID");

# Create file for resetting to original file after modifications
swap.merged_ordered=merged_ordered

# Check that the number of rows after merging is the same
if(nrow(Cort) != nrow(merged_ordered)){
       cat(paste0('WARNING: ', fsfile, ' and Covariates.csv have non-matching SubjIDs.','\n'))
       cat('Please make sure the number of subjects in your merged data set are as expected.','\n')
       cat(paste0('The number of SubjIDs in ', fsfile, ' is: ',nrow(Cort),'\n'))
       cat('The number of SubjIDs in the merged_ordered data set is: ',nrow(merged_ordered),'\n')
}

cat('Calculating demographics for ', fsfile,'\n')

# Get raw means for each of the structures
raw.means=colMeans(merged_ordered[(ncol(Covs)+1):ncol(merged_ordered)], na.rm=T)

# Get raw sd and number of subjects included for each of the structures
sd.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
n.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
min.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
max.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
for(z in (ncol(Covs)+1):ncol(merged_ordered)){
	sd.raw[z-ncol(Covs)]=sd(merged_ordered[,z], na.rm=T)
	n.raw[z-ncol(Covs)]=length(merged_ordered[which(!is.na(merged_ordered[,z])),z])
	min.raw[z-ncol(Covs)]=min(merged_ordered[,z], na.rm=T)
    max.raw[z-ncol(Covs)]=max(merged_ordered[,z], na.rm=T)
}

# Save raw values
save(raw.means, sd.raw, n.raw, min.raw, max.raw, file=paste0("RawMeans_",filetype,".Rdata"))

# Get raw means for each of the structures for the patients
patients=which(merged_ordered$Dx==1)
raw.means=colMeans(merged_ordered[patients,(ncol(Covs)+1):ncol(merged_ordered)], na.rm=T)

# Get raw sd and number of subjects included for each of the structures for the patients
sd.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
n.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
min.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
max.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
for(z in (ncol(Covs)+1):ncol(merged_ordered)){
        sd.raw[z-ncol(Covs)]=sd(merged_ordered[patients,z], na.rm=T)
        n.raw[z-ncol(Covs)]=length(merged_ordered[which(!is.na(merged_ordered[patients,z])),z])
        min.raw[z-ncol(Covs)]=min(merged_ordered[patients,z], na.rm=T)
        max.raw[z-ncol(Covs)]=max(merged_ordered[patients,z], na.rm=T)
}

# Save raw values
save(raw.means, sd.raw, n.raw, min.raw, max.raw, file=paste0("RawMeans_patients_",filetype,".Rdata"))    


# Get raw means for each of the structures for the controls
controls=which(merged_ordered$Dx==0)
raw.means=colMeans(merged_ordered[controls,(ncol(Covs)+1):ncol(merged_ordered)], na.rm=T)

# Get raw sd and number of subjects included for each of the structures for the patients
sd.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
n.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
min.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
max.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
for(z in (ncol(Covs)+1):ncol(merged_ordered)){
        sd.raw[z-ncol(Covs)]=sd(merged_ordered[controls,z], na.rm=T)
        n.raw[z-ncol(Covs)]=length(merged_ordered[which(!is.na(merged_ordered[controls,z])),z])
        min.raw[z-ncol(Covs)]=min(merged_ordered[controls,z], na.rm=T)
        max.raw[z-ncol(Covs)]=max(merged_ordered[controls,z], na.rm=T)
}

# Save raw values
save(raw.means, sd.raw, n.raw, min.raw, max.raw, file=paste0("RawMeans_controls_",filetype,".Rdata"))  


# Get raw means for each of the structures for the recurrent patients
recurpatients=which(merged_ordered$Recur==2)
raw.means=colMeans(merged_ordered[recurpatients,(ncol(Covs)+1):ncol(merged_ordered)], na.rm=T)

# Get raw sd and number of subjects included for each of the structures for the recurrent patients
sd.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
n.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
min.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
max.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
for(z in (ncol(Covs)+1):ncol(merged_ordered)){
        sd.raw[z-ncol(Covs)]=sd(merged_ordered[recurpatients,z], na.rm=T)
        n.raw[z-ncol(Covs)]=length(merged_ordered[which(!is.na(merged_ordered[recurpatients,z])),z])
        min.raw[z-ncol(Covs)]=min(merged_ordered[recurpatients,z], na.rm=T)
        max.raw[z-ncol(Covs)]=max(merged_ordered[recurpatients,z], na.rm=T)
}

# Save raw values
save(raw.means, sd.raw, n.raw, min.raw, max.raw, file=paste0("RawMeans_recurpatients_",filetype,".Rdata"))     

# Get raw means for each of the structures for the first episode patients
firstpatients=which(merged_ordered$Recur==1)
raw.means=colMeans(merged_ordered[firstpatients,(ncol(Covs)+1):ncol(merged_ordered)], na.rm=T)

# Get raw sd and number of subjects included for each of the structures for the first eisode patients
sd.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
n.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
min.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
max.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
for(z in (ncol(Covs)+1):ncol(merged_ordered)){
        sd.raw[z-ncol(Covs)]=sd(merged_ordered[firstpatients,z], na.rm=T)
        n.raw[z-ncol(Covs)]=length(merged_ordered[which(!is.na(merged_ordered[firstpatients,z])),z])
        min.raw[z-ncol(Covs)]=min(merged_ordered[firstpatients,z], na.rm=T)
        max.raw[z-ncol(Covs)]=max(merged_ordered[firstpatients,z], na.rm=T)
}

# Save raw values
save(raw.means, sd.raw, n.raw, min.raw, max.raw, file=paste0("RawMeans_firstpatients_",filetype,".Rdata"))    

# Get raw means for each of the structures for the acutely depressed patients
acutepatients=which(merged_ordered$Rem==2)
raw.means=colMeans(merged_ordered[acutepatients,(ncol(Covs)+1):ncol(merged_ordered)], na.rm=T)

# Get raw sd and number of subjects included for each of the structures for the acutely depressed patients
sd.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
n.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
min.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
max.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
for(z in (ncol(Covs)+1):ncol(merged_ordered)){
        sd.raw[z-ncol(Covs)]=sd(merged_ordered[acutepatients,z], na.rm=T)
        n.raw[z-ncol(Covs)]=length(merged_ordered[which(!is.na(merged_ordered[acutepatients,z])),z])
        min.raw[z-ncol(Covs)]=min(merged_ordered[acutepatients,z], na.rm=T)
        max.raw[z-ncol(Covs)]=max(merged_ordered[acutepatients,z], na.rm=T)
}

# Save raw values
save(raw.means, sd.raw, n.raw, min.raw, max.raw, file=paste0("RawMeans_acutepatients_",filetype,".Rdata"))    

# Get raw means for each of the structures for the remitted patients
rempatients=which(merged_ordered$Rem==1)
raw.means=colMeans(merged_ordered[rempatients,(ncol(Covs)+1):ncol(merged_ordered)], na.rm=T)

# Get raw sd and number of subjects included for each of the structures for the remitted patients
sd.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
n.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
min.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
max.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
for(z in (ncol(Covs)+1):ncol(merged_ordered)){
        sd.raw[z-ncol(Covs)]=sd(merged_ordered[rempatients,z], na.rm=T)
        n.raw[z-ncol(Covs)]=length(merged_ordered[which(!is.na(merged_ordered[rempatients,z])),z])
        min.raw[z-ncol(Covs)]=min(merged_ordered[rempatients,z], na.rm=T)
        max.raw[z-ncol(Covs)]=max(merged_ordered[rempatients,z], na.rm=T)
}

# Save raw values
save(raw.means, sd.raw, n.raw, min.raw, max.raw, file=paste0("RawMeans_rempatients_",filetype,".Rdata"))

# Get raw means for each of the structures for the antidepressant users
ADpatients=which(merged_ordered$AD==2)
raw.means=colMeans(merged_ordered[ADpatients,(ncol(Covs)+1):ncol(merged_ordered)], na.rm=T)

# Get raw sd and number of subjects included for each of the structures for the antidepressant users
sd.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
n.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
min.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
max.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
for(z in (ncol(Covs)+1):ncol(merged_ordered)){
        sd.raw[z-ncol(Covs)]=sd(merged_ordered[ADpatients,z], na.rm=T)
        n.raw[z-ncol(Covs)]=length(merged_ordered[which(!is.na(merged_ordered[ADpatients,z])),z])
        min.raw[z-ncol(Covs)]=min(merged_ordered[ADpatients,z], na.rm=T)
        max.raw[z-ncol(Covs)]=max(merged_ordered[ADpatients,z], na.rm=T)
}

# Save raw values
save(raw.means, sd.raw, n.raw, min.raw, max.raw, file=paste0("RawMeans_ADpatients_",filetype,".Rdata"))  

# Get raw means for each of the structures for the non-antidepressant users
noADpatients=which(merged_ordered$AD==1)
raw.means=colMeans(merged_ordered[noADpatients,(ncol(Covs)+1):ncol(merged_ordered)], na.rm=T)

# Get raw sd and number of subjects included for each of the structures for the non-antidepressant users
sd.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
n.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
min.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
max.raw=rep(NA,(ncol(merged_ordered)-ncol(Covs)))
for(z in (ncol(Covs)+1):ncol(merged_ordered)){
        sd.raw[z-ncol(Covs)]=sd(merged_ordered[noADpatients,z], na.rm=T)
        n.raw[z-ncol(Covs)]=length(merged_ordered[which(!is.na(merged_ordered[noADpatients,z])),z])
        min.raw[z-ncol(Covs)]=min(merged_ordered[noADpatients,z], na.rm=T)
        max.raw[z-ncol(Covs)]=max(merged_ordered[noADpatients,z], na.rm=T)
}

# Save raw values
save(raw.means, sd.raw, n.raw, min.raw, max.raw, file=paste0("RawMeans_noADpatients_",filetype,".Rdata"))        

# Get demographics
age.mu=mean(merged_ordered$Age,na.rm=T) #raw age mean
age.sd=sd(merged_ordered$Age,na.rm=T) #raw age sd
age.range=range(merged_ordered$Age,na.rm=T) #raw age range
age.mu.dx0=mean(merged_ordered$Age[which(merged_ordered$Dx==0)],na.rm=T) #age mean for ctls
age.sd.dx0=sd(merged_ordered$Age[which(merged_ordered$Dx==0)],na.rm=T) #age sd for ctls
age.range.dx0=range(merged_ordered$Age[which(merged_ordered$Dx==0)],na.rm=T) #age range for ctls
age.mu.dx1=mean(merged_ordered$Age[which(merged_ordered$Dx==1)],na.rm=T) #age mean for patients
age.sd.dx1=sd(merged_ordered$Age[which(merged_ordered$Dx==1)],na.rm=T) #age sd for patients
age.range.dx1=range(merged_ordered$Age[which(merged_ordered$Dx==1)],na.rm=T) #age range for patients
age.mu.recur=mean(merged_ordered$Age[which(merged_ordered$Recur==2)],na.rm=T) #age mean for recurrent patients
age.sd.recur=sd(merged_ordered$Age[which(merged_ordered$Recur==2)],na.rm=T) #age sd for recurrent patients
age.range.recur=range(merged_ordered$Age[which(merged_ordered$Recur==2)],na.rm=T)  #age range for recurrent patients
age.mu.first=mean(merged_ordered$Age[which(merged_ordered$Recur==1)],na.rm=T)  #age mean for first episode patients
age.sd.first=sd(merged_ordered$Age[which(merged_ordered$Recur==1)],na.rm=T)  #age sd for first episode patients
age.range.first=range(merged_ordered$Age[which(merged_ordered$Recur==1)],na.rm=T)   #age range for first episode patients
age.mu.acute=mean(merged_ordered$Age[which(merged_ordered$Rem==2)],na.rm=T)   #age mean for acutely depressed patients
age.sd.acute=sd(merged_ordered$Age[which(merged_ordered$Rem==2)],na.rm=T)   #age sd for acutely depressed patients
age.range.acute=range(merged_ordered$Age[which(merged_ordered$Rem==2)],na.rm=T)   #age range for acutely depressed patients
age.mu.rem=mean(merged_ordered$Age[which(merged_ordered$Rem==1)],na.rm=T)   #age mean for remitted patients
age.sd.rem=sd(merged_ordered$Age[which(merged_ordered$Rem==1)],na.rm=T)   #age sd for remitted patients
age.range.rem=range(merged_ordered$Age[which(merged_ordered$Rem==1)],na.rm=T)   #age range for remitted patients
age.mu.AD=mean(merged_ordered$Age[which(merged_ordered$AD==2)],na.rm=T)   #age mean for antidepressant users
age.sd.AD=sd(merged_ordered$Age[which(merged_ordered$AD==2)],na.rm=T)   #age sd for antidepressant users
age.range.AD=range(merged_ordered$Age[which(merged_ordered$AD==2)],na.rm=T)   #age range for antidepressant users
age.mu.noAD=mean(merged_ordered$Age[which(merged_ordered$AD==1)],na.rm=T)   #age mean for non-antidepressant users
age.sd.noAD=sd(merged_ordered$Age[which(merged_ordered$AD==1)],na.rm=T)   #age sd for non-antidepressant users
age.range.noAD=range(merged_ordered$Age[which(merged_ordered$AD==1)],na.rm=T)  #age range for non-antidepressant users
AO.mu.dx1=mean(merged_ordered$AO[which(merged_ordered$Dx==1)],na.rm=T) #age of onset MDD mean for patients
AO.sd.dx1=sd(merged_ordered$AO[which(merged_ordered$Dx==1)],na.rm=T) #age of onset MDD sd for patients
AO.range.dx1=range(merged_ordered$AO[which(merged_ordered$Dx==1)],na.rm=T) #age of onset MDD range for patients
AO.mu.first=mean(merged_ordered$AO[which(merged_ordered$Recur==1)],na.rm=T) #age of onset MDD mean for first episode patients
AO.sd.first=sd(merged_ordered$AO[which(merged_ordered$Recur==1)],na.rm=T) #age of onset MDD sd for first episode patients
AO.range.first=range(merged_ordered$AO[which(merged_ordered$Recur==1)],na.rm=T) #age of onset MDD range for first episode patients
AO.mu.recur=mean(merged_ordered$AO[which(merged_ordered$Recur==2)],na.rm=T) #age of onset MDD mean for recurrent patients
AO.sd.recur=sd(merged_ordered$AO[which(merged_ordered$Recur==2)],na.rm=T) #age of onset MDD sd for recurrent patients
AO.range.recur=range(merged_ordered$AO[which(merged_ordered$Recur==2)],na.rm=T) #age of onset MDD range for recurrent patients
AO.mu.AD=mean(merged_ordered$AO[which(merged_ordered$AD==2)],na.rm=T) #age of onset MDD mean for antidepressants users
AO.sd.AD=sd(merged_ordered$AO[which(merged_ordered$AD==2)],na.rm=T) #age of onset MDD sd for antidepressants users
AO.range.AD=range(merged_ordered$AO[which(merged_ordered$AD==2)],na.rm=T) #age of onset MDD range for antidepressants users
AO.mu.noAD=mean(merged_ordered$AO[which(merged_ordered$AD==1)],na.rm=T) #age of onset MDD mean for non-antidepressants users
AO.sd.noAD=sd(merged_ordered$AO[which(merged_ordered$AD==1)],na.rm=T) #age of onset MDD sd for non-antidepressants users
AO.range.noAD=range(merged_ordered$AO[which(merged_ordered$AD==1)],na.rm=T) #age of onset MDD range for non-antidepressants users
Sev.mu.dx1=mean(merged_ordered$Sev[which(merged_ordered$Dx==1)],na.rm=T) #severity MDD mean for patients
Sev.sd.dx1=sd(merged_ordered$Sev[which(merged_ordered$Dx==1)],na.rm=T) #severity MDD sd for patients
Sev.range.dx1=range(merged_ordered$Sev[which(merged_ordered$Dx==1)],na.rm=F) #severity MDD range for patients
Sev.mu.first=mean(merged_ordered$Sev[which(merged_ordered$Recur==1)],na.rm=T) #severity MDD mean for first episode patients
Sev.sd.first=sd(merged_ordered$Sev[which(merged_ordered$Recur==1)],na.rm=T) #severity MDD sd for first episode patients
Sev.range.first=range(merged_ordered$Sev[which(merged_ordered$Recur==1)],na.rm=F) #severity MDD range for first episode patients
Sev.mu.recur=mean(merged_ordered$Sev[which(merged_ordered$Recur==2)],na.rm=T) #severity MDD mean for recurrent patients
Sev.sd.recur=sd(merged_ordered$Sev[which(merged_ordered$Recur==2)],na.rm=T) #severity MDD sd for recurrent patients
Sev.range.recur=range(merged_ordered$Sev[which(merged_ordered$Recur==2)],na.rm=F) #severity MDD range for recurrent patients
Sev.mu.AD=mean(merged_ordered$Sev[which(merged_ordered$AD==2)],na.rm=T) #severity MDD mean for antidepressants users
Sev.sd.AD=sd(merged_ordered$Sev[which(merged_ordered$AD==2)],na.rm=T) #severity MDD sd for antidepressants users
Sev.range.AD=range(merged_ordered$Sev[which(merged_ordered$AD==2)],na.rm=F) #severity MDD range for antidepressants users
Sev.mu.noAD=mean(merged_ordered$Sev[which(merged_ordered$AD==1)],na.rm=T) #severity MDD mean for non-antidepressants users
Sev.sd.noAD=sd(merged_ordered$Sev[which(merged_ordered$AD==1)],na.rm=T) #severity MDD sd for non-antidepressants users
Sev.range.noAD=range(merged_ordered$Sev[which(merged_ordered$AD==1)],na.rm=F) #severity MDD range for non-antidepressants users
HDRS.mu.dx1=mean(merged_ordered$HDRS[which(merged_ordered$Dx==1)],na.rm=T) #severity MDD mean for patients
HDRS.sd.dx1=sd(merged_ordered$HDRS[which(merged_ordered$Dx==1)],na.rm=T) #severity MDD sd for patients
HDRS.range.dx1=range(merged_ordered$HDRS [which(merged_ordered$Dx==1)],na.rm=T) #severity MDD range for patients
HDRS.mu.first=mean(merged_ordered$HDRS [which(merged_ordered$Recur==1)],na.rm=T) #severity MDD mean for first episode patients
HDRS.sd.first=sd(merged_ordered$HDRS [which(merged_ordered$Recur==1)],na.rm=T) #severity MDD sd for first episode patients
HDRS.range.first=range(merged_ordered$HDRS[which(merged_ordered$Recur==1)],na.rm=T) #severity MDD range for first episode patients
HDRS.mu.recur=mean(merged_ordered$HDRS[which(merged_ordered$Recur==2)],na.rm=T) #severity MDD mean for recurrent patients
HDRS.sd.recur=sd(merged_ordered$HDRS[which(merged_ordered$Recur==2)],na.rm=T) #severity MDD sd for recurrent patients
HDRS.range.recur=range(merged_ordered$HDRS[which(merged_ordered$Recur==2)],na.rm=T) #severity MDD range for recurrent patients
HDRS.mu.AD=mean(merged_ordered$HDRS[which(merged_ordered$AD==2)],na.rm=T) #severity MDD mean for AD users
HDRS.sd.AD=sd(merged_ordered$HDRS[which(merged_ordered$AD==2)],na.rm=T) #severity MDD sd for AD users
HDRS.range.AD=range(merged_ordered$HDRS[which(merged_ordered$AD==2)],na.rm=T) #severity MDD range for AD users
HDRS.mu.noAD=mean(merged_ordered$HDRS[which(merged_ordered$AD==1)],na.rm=T) #severity MDD mean for AD free patients
HDRS.sd.noAD=sd(merged_ordered$HDRS[which(merged_ordered$AD==1)],na.rm=T) #severity MDD sd for AD free patients
HDRS.range.noAD=range(merged_ordered$HDRS[which(merged_ordered$AD==1)],na.rm=T) #severity MDD range for AD free patients
BDI.mu.dx1=mean(merged_ordered$BDI[which(merged_ordered$Dx==1)],na.rm=T) #severity MDD mean for patients
BDI.sd.dx1=sd(merged_ordered$BDI[which(merged_ordered$Dx==1)],na.rm=T) #severity MDD sd for patients
BDI.range.dx1=range(merged_ordered$BDI [which(merged_ordered$Dx==1)],na.rm=T) #severity MDD range for patients
BDI.mu.first=mean(merged_ordered$BDI [which(merged_ordered$Recur==1)],na.rm=T) #severity MDD mean for first episode patients
BDI.sd.first=sd(merged_ordered$BDI [which(merged_ordered$Recur==1)],na.rm=T) #severity MDD sd for first episode patients
BDI.range.first=range(merged_ordered$BDI[which(merged_ordered$Recur==1)],na.rm=T) #severity MDD range for first episode patients
BDI.mu.recur=mean(merged_ordered$BDI[which(merged_ordered$Recur==2)],na.rm=T) #severity MDD mean for recurrent patients
BDI.sd.recur=sd(merged_ordered$BDI[which(merged_ordered$Recur==2)],na.rm=T) #severity MDD sd for recurrent patients
BDI.range.recur=range(merged_ordered$BDI[which(merged_ordered$Recur==2)],na.rm=T) #severity MDD range for recurrent patients
BDI.mu.AD=mean(merged_ordered$BDI[which(merged_ordered$AD==2)],na.rm=T) #severity MDD mean for AD users
BDI.sd.AD=sd(merged_ordered$BDI[which(merged_ordered$AD==2)],na.rm=T) #severity MDD sd for AD users
BDI.range.AD=range(merged_ordered$BDI[which(merged_ordered$AD==2)],na.rm=T) #severity MDD range for AD users
BDI.mu.noAD=mean(merged_ordered$BDI[which(merged_ordered$AD==1)],na.rm=T) #severity MDD mean for AD free patients
BDI.sd.noAD=sd(merged_ordered$BDI[which(merged_ordered$AD==1)],na.rm=T) #severity MDD sd for AD free patients
BDI.range.noAD=range(merged_ordered$BDI[which(merged_ordered$AD==1)],na.rm=T) #severity MDD range for AD free patients
Epi.mu.dx1=mean(merged_ordered$Epi[which(merged_ordered$Dx==1)],na.rm=T) #number of episodes MDD mean for patients
Epi.sd.dx1=sd(merged_ordered$Epi[which(merged_ordered$Dx==1)],na.rm=T) #number of episodes MDD sd for patients
Epi.range.dx1=range(merged_ordered$Epi[which(merged_ordered$Dx==1)],na.rm=F) #number of episodes MDD range for patients
Epi.mu.first=mean(merged_ordered$Epi[which(merged_ordered$Recur==1)],na.rm=T) #number of episodes MDD mean for first episode patients
Epi.sd.first=sd(merged_ordered$Epi[which(merged_ordered$Recur==1)],na.rm=T) #number of episodes MDD sd for first episode patients
Epi.range.first=range(merged_ordered$Epi[which(merged_ordered$Recur==1)],na.rm=F) #number of episodes MDD range for first episode patients
Epi.mu.recur=mean(merged_ordered$Epi[which(merged_ordered$Recur==2)],na.rm=T) #number of episodes MDD mean for recurrent patients
Epi.sd.recur=sd(merged_ordered$Epi[which(merged_ordered$Recur==2)],na.rm=T) #number of episodes MDD sd for recurrent patients
Epi.range.recur=range(merged_ordered$Epi[which(merged_ordered$Recur==2)],na.rm=F) #number of episodes MDD range for recurrent patients
Epi.mu.AD=mean(merged_ordered$Epi[which(merged_ordered$AD==2)],na.rm=T) #number of episodes MDD mean for AD users
Epi.sd.AD=sd(merged_ordered$Epi[which(merged_ordered$AD==2)],na.rm=T) #number of episodes MDD sd for AD users
Epi.range.AD=range(merged_ordered$Epi[which(merged_ordered$AD==2)],na.rm=F) #number of episodes MDD range for AD users
Epi.mu.noAD=mean(merged_ordered$Epi[which(merged_ordered$AD==1)],na.rm=T) #number of episodes MDD mean for AD free patients
Epi.sd.noAD=sd(merged_ordered$Epi[which(merged_ordered$AD==1)],na.rm=T) #number of episodes MDD sd for AD free patients
Epi.range.noAD=range(merged_ordered$Epi[which(merged_ordered$AD==1)],na.rm=F) #number of episodes MDD range for AD free patients
ADcur.mu.dx1=mean(merged_ordered$ADcur[which(merged_ordered$Dx==1)],na.rm=T) #duration current AD use MDD mean for patients
ADcur.sd.dx1=sd(merged_ordered$ADcur[which(merged_ordered$Dx==1)],na.rm=T) #duration current AD use MDD sd for patients
ADcur.range.dx1=range(merged_ordered$ADcur[which(merged_ordered$Dx==1)],na.rm=F) #duration current AD use MDD range for patients
ADcur.mu.first=mean(merged_ordered$ADcur[which(merged_ordered$Recur==1)],na.rm=T) #duration current AD use MDD mean for first episode patients
ADcur.sd.first=sd(merged_ordered$ADcur[which(merged_ordered$Recur==1)],na.rm=T) #duration current AD use MDD sd for first episode patients
ADcur.range.first=range(merged_ordered$ADcur[which(merged_ordered$Recur==1)],na.rm=F) #nduration current AD use MDD range for first episode patients
ADcur.mu.recur=mean(merged_ordered$ADcur[which(merged_ordered$Recur==2)],na.rm=T) #duration current AD use MDD mean for recurrent patients
ADcur.sd.recur=sd(merged_ordered$ADcur[which(merged_ordered$Recur==2)],na.rm=T) #duration current AD use MDD sd for recurrent patients
ADcur.range.recur=range(merged_ordered$ADcur[which(merged_ordered$Recur==2)],na.rm=F) #duration current AD use MDD range for recurrent patients
ADcur.mu.AD=mean(merged_ordered$ADcur[which(merged_ordered$AD==2)],na.rm=T) #duration current AD use MDD mean for AD users
ADcur.sd.AD=sd(merged_ordered$ADcur[which(merged_ordered$AD==2)],na.rm=T) #duration current AD use MDD sd for AD users
ADcur.range.AD=range(merged_ordered$ADcur[which(merged_ordered$AD==2)],na.rm=F) #duration current AD use MDD range for AD users
ADcur.mu.noAD=mean(merged_ordered$ADcur[which(merged_ordered$AD==1)],na.rm=T) #duration current AD use MDD mean for AD free patients
ADcur.sd.noAD=sd(merged_ordered$ADcur[which(merged_ordered$AD==1)],na.rm=T) #duration current AD use MDD sd for AD free patients
ADcur.range.noAD=range(merged_ordered$ADcur[which(merged_ordered$AD==1)],na.rm=F) #duration current AD use MDD range for AD free patients

n.fem=length(which(merged_ordered$Sex==2))   # Women
n.mal=length(which(merged_ordered$Sex==1))   # Men

# Check that Sex was coded properly
if((n.fem + n.mal) != length(merged_ordered$Sex)){
	stop('Did you remember to code the Sex covariate as Males=1 and Females=2?\n')
}
n.fem.dx0=length(which(merged_ordered$Sex==2 & merged_ordered$Dx==0))   # Women ctls
n.mal.dx0=length(which(merged_ordered$Sex==1 & merged_ordered$Dx==0))   # Men ctls
n.fem.dx1=length(which(merged_ordered$Sex==2 & merged_ordered$Dx==1))   # Women patients
n.mal.dx1=length(which(merged_ordered$Sex==1 & merged_ordered$Dx==1))   # Men patients
n.fem.recur=length(which(merged_ordered$Sex==2 & merged_ordered$Recur==2))   # Women recurrent patients
n.mal.recur=length(which(merged_ordered$Sex==1 & merged_ordered$Recur==2))   # Men recurrent patients
n.fem.first=length(which(merged_ordered$Sex==2 & merged_ordered$Recur==1))   # Women first episode patients
n.mal.first=length(which(merged_ordered$Sex==1 & merged_ordered$Recur==1))   # Men first episode patients
n.fem.acute=length(which(merged_ordered$Sex==2 & merged_ordered$Rem==2))   # Women acutely depressed patients
n.mal.acute=length(which(merged_ordered$Sex==1 & merged_ordered$Rem==2))   # Men acutely depressed patients
n.fem.rem=length(which(merged_ordered$Sex==2 & merged_ordered$Rem==1))   # Women remitted patients
n.mal.rem=length(which(merged_ordered$Sex==1 & merged_ordered$Rem==1))   # Men remitted patients
n.fem.AD=length(which(merged_ordered$Sex==2 & merged_ordered$AD==2))   # Women antidepressant users
n.mal.AD=length(which(merged_ordered$Sex==1 & merged_ordered$AD==2))   # Men antidepressant users
n.fem.noAD=length(which(merged_ordered$Sex==2 & merged_ordered$AD==1))   # Women non-antidepressant users
n.mal.noAD=length(which(merged_ordered$Sex==1 & merged_ordered$AD==1))   # Men non-antidepressant users

n.dx0=length(which(merged_ordered$Dx==0))  # Total number of ctls
n.dx1=length(which(merged_ordered$Dx==1))  # Total number of patients
n.recur=length(which(merged_ordered$Recur==2))   # Total number of recurrent patients
n.first=length(which(merged_ordered$Recur==1))   # Total number of first episode patients
n.acute=length(which(merged_ordered$Rem==2))   # Total number of acutely depressed patients
n.rem=length(which(merged_ordered$Rem==1))   # Total number of remitted patients
n.AD=length(which(merged_ordered$AD==2))   # Total number of antidepressant users
n.noAD=length(which(merged_ordered$AD==1))   # Total number of non-antidepressant users
n.acute.first=length(which(merged_ordered$Recur==1 & merged_ordered$Rem==2))   # first episode patients acutely depressed 
n.acute.recur=length(which(merged_ordered$Recur==2 & merged_ordered$Rem==2))   # recurrent patients acutely depressed 
n.rem.first=length(which(merged_ordered$Recur==1 & merged_ordered$Rem==1))   # first episode remitted patients
n.rem.recur=length(which(merged_ordered$Recur==2 & merged_ordered$Rem==1))   # recurrent remitted patients
n.AD.first=length(which(merged_ordered$Recur==1 & merged_ordered$AD==2))   # first episode antidepressant users
n.AD.recur=length(which(merged_ordered$Recur==2 & merged_ordered$AD==2))   # recurrent antidepressant users
n.noAD.first=length(which(merged_ordered$Recur==1 & merged_ordered$AD==1))   # first episode non-antidepressant users
n.noAD.recur=length(which(merged_ordered$Recur==2 & merged_ordered$AD==1))   # recurrent non-antidepressant users

# Save demographic info
save(age.mu, age.sd, age.range, age.mu.dx0, age.sd.dx0, age.range.dx0, age.mu.dx1, age.sd.dx1, age.range.dx1,
age.mu.recur, age.sd.recur, age.range.recur, age.mu.first, age.sd.first, age.range.first, age.mu.acute, age.sd.acute, age.range.acute, age.mu.rem, age.sd.rem, age.range.rem, age.mu.AD, age.sd.AD, age.range.AD, age.mu.noAD, age.sd.noAD, age.range.noAD, AO.mu.dx1, AO.sd.dx1, AO.range.dx1, Sev.mu.dx1, Sev.sd.dx1, Sev.range.dx1, n.fem, n.mal, n.fem.dx0, n.mal.dx0, n.fem.dx1, n.mal.dx1, n.fem.recur, n.mal.recur, n.fem.first, n.mal.first, n.fem.acute, n.mal.acute, n.fem.rem, n.mal.rem, n.fem.AD, n.mal.AD, n.fem.noAD, n.mal.noAD, n.dx0, n.dx1, n.recur, n.first, n.acute, n.rem, n.AD, n.noAD, AO.mu.first, AO.sd.first, AO.range.first, AO.mu.recur, AO.sd.recur, AO.range.recur, Sev.mu.first, Sev.sd.first, Sev.range.first, Sev.mu.recur, Sev.sd.recur, Sev.range.recur, n.acute.first, n.acute.recur, n.rem.first, n.rem.recur, n.AD.first, n.AD.recur, n.noAD.first, n.noAD.recur, AO.mu.AD, AO.sd.AD, AO.range.AD, AO.mu.noAD, AO.sd.noAD, AO.range.noAD, Sev.mu.AD, Sev.sd.AD, Sev.range.AD, Sev.mu.noAD, Sev.sd.noAD, Sev.range.noAD, HDRS.mu.dx1, HDRS.sd.dx1, HDRS.range.dx1,HDRS.mu.first, HDRS.sd.first, HDRS.range.first, HDRS.mu.recur, HDRS.sd.recur, HDRS.range.recur, HDRS.mu.AD, HDRS.sd.AD, HDRS.range.AD, HDRS.mu.noAD, HDRS.sd.noAD, HDRS.range.noAD, BDI.mu.dx1, BDI.sd.dx1, BDI.range.dx1,BDI.mu.first, BDI.sd.first, BDI.range.first, BDI.mu.recur, BDI.sd.recur, BDI.range.recur, BDI.mu.AD, BDI.sd.AD, BDI.range.AD, BDI.mu.noAD, BDI.sd.noAD, BDI.range.noAD, Epi.mu.dx1, Epi.sd.dx1, Epi.range.dx1,Epi.mu.first, Epi.sd.first, Epi.range.first, Epi.mu.recur, Epi.sd.recur, Epi.range.recur, Epi.mu.AD, Epi.sd.AD, Epi.range.AD, Epi.mu.noAD, Epi.sd.noAD, Epi.range.noAD, ADcur.mu.dx1, ADcur.sd.dx1, ADcur.range.dx1,ADcur.mu.first, ADcur.sd.first, ADcur.range.first, ADcur.mu.recur, ADcur.sd.recur, ADcur.range.recur, ADcur.mu.AD, ADcur.sd.AD, ADcur.range.AD, ADcur.mu.noAD, ADcur.sd.noAD, ADcur.range.noAD, file=paste0("Demographics_",filetype,".Rdata"))

cat('Done calculating demographics for ', fsfile,'\n')

# Regression Analysis

# Functions used in the code for Cohens d
d.t.unpaired<-function(t.val,n1,n2){
  d<-t.val*sqrt((n1+n2)/(n1*n2))
  names(d)<-"effect size d"
  return(d)
}

partial.d<-function(t.val,df,n1,n2){
  d<-t.val*(n1+n2)/(sqrt(n1*n2)*sqrt(df))
  names(d)<-"effect size d"
  return(d)
}

CI1<-function(ES,se){
  ci<-c((ES-(1.96)*se),(ES+(1.96)*se))
  names(ci)<-c("95% CI lower","95% CI upper")
  return(ci)
}

se.d2<-function(d,n1,n2){
  se<-sqrt((n1+n2)/(n1*n2)+(d^2)/(2*(n1+n2-2)))
  names(se)<-"se for d"
  return(se)
}


# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# %                                                    %
# %                 START OF ANALYSES                  %
# %                                                    %
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# Attach main file
attach(merged_ordered)


# 1. MDD patients vs controls
# ===========================

# Check that there is enough data
if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 1. MDD patients vs controls\n')

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
N_of_tests = ncol(merged_ordered)-ncol(Covs)-rightmargin
d.cort	   	=rep(NA,N_of_tests)
se.cort		=rep(NA,N_of_tests)
low.ci.cort	=rep(NA,N_of_tests)
up.ci.cort	=rep(NA,N_of_tests)
n.controls	=rep(NA,N_of_tests)
n.patients	=rep(NA,N_of_tests)

# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + "
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 1. MDD patients vs controls\n')}



# 2. Diagnosis by Sex interaction (all MDD patients vs controls)
# ==============================================================

# Check that there is enough data
if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 2. Diagnosis by Sex interaction (all MDD patients vs controls)\n')
	
models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + factor(Sex) + factor(Dx):factor(Sex)", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference

	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[(6 + AgeSq_and_interactions + n.sites),3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_DxBySex_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_DxBySex_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 2. Diagnosis by Sex interaction (all MDD patients vs controls)\n')}



# 3. Diagnosis by Age interaction (all MDD patients vs controls)
# ==============================================================

# Check that there is enough data
if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 3. Diagnosis by Age interaction (all MDD patients vs controls)\n')

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + factor(Sex) + factor(Dx):Age", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[(6 + AgeSq_and_interactions + n.sites),3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_DxByAge_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_DxByAge_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 3. Diagnosis by Age interaction (all MDD patients vs controls)\n')}



# 4. Recurrent patients vs controls
# =================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[((merged_ordered$Recur!=1) & !(is.na(merged_ordered$Recur))),]
attach(merged_ordered)

# Check that there is enough data
if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 4. Recurrent patients vs controls\n')

# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_Recur_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_Recur_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 4. Recurrent patients vs controls\n')}


# 5. First episode patients vs controls
# =====================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[((merged_ordered$Recur!=2) & !(is.na(merged_ordered$Recur))),]
attach(merged_ordered)

if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 5. First episode patients vs controls\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_First_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_First_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 5. First episode patients vs controls\n')}



# 6. Recurrent patients vs first episode patients
# ===============================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.first=rep(NA,N_of_tests)
n.recurrent=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[((merged_ordered$Recur!=0) & !(is.na(merged_ordered$Recur))),]
attach(merged_ordered)

if((length(which(merged_ordered$Recur==1)) > 7) & (length(which(merged_ordered$Recur==2)) > 7)){
cat('Running: 6. Recurrent patients vs first episode patients\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Recur) + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.first[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	n.recurrent[x-ncol(Covs)] = length(which(tmp$model[,2] == 2))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.first[x-ncol(Covs)],n.recurrent[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.first[x-ncol(Covs)],n.recurrent[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.first,n.recurrent, file=paste0("EffectSizes_MDDvCTL_FirstRecur_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_FirstRecur_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 6. Recurrent patients vs first episode patients\n')}


# 7. Antidepressant users vs controls
# ===================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[((merged_ordered$AD!=1) & !(is.na(merged_ordered$AD))),]
attach(merged_ordered)

if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 7. Antidepressant users vs controls\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_AD_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_AD_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 7. Antidepressant users vs controls\n')}



# 8. non-antidepressant users vs controls
# =======================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[((merged_ordered$AD!=2) & !(is.na(merged_ordered$AD))),]
attach(merged_ordered)

if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 8. non-antidepressant users vs controls\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_noAD_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_noAD_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 8. non-antidepressant users vs controls\n')}



# 9. Antidepressant users vs non-antidepressant users
# ===================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.noAD=rep(NA,N_of_tests)
n.AD=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[((merged_ordered$AD!=0) & !(is.na(merged_ordered$AD))),]
attach(merged_ordered)

if((length(which(merged_ordered$AD==1)) > 7) & (length(which(merged_ordered$AD==2)) > 7)){
cat('Running: 9. Antidepressant users vs non-antidepressant users\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(AD) + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.noAD[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	n.AD[x-ncol(Covs)] = length(which(tmp$model[,2] == 2))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.noAD[x-ncol(Covs)],n.AD[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.noAD[x-ncol(Covs)],n.AD[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.noAD,n.AD, file=paste0("EffectSizes_MDDvCTL_ADnoAD_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_ADnoAD_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 9. Antidepressant users vs non-antidepressant users\n')}



# 10. Regression number of episodes in MDD patients
# =================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
r.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[((merged_ordered$Dx==1) & !(is.na(merged_ordered$Epi))),]
attach(merged_ordered)

if(length(which(merged_ordered$Dx==1)) > 7){
cat('Running: 10. Regression number of episodes in MDD patients\n')

# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ Epi + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.patients[x-ncol(Covs)] = length(tmp$model[,2])

	partcor.i <- pcor.test(tmp$model[1],tmp$model[,2],tmp$model[,c(3:(ncol(tmp$model)-AgeSq_and_interactions*2))])	
	r.cort[x-ncol(Covs)]=partcor.i[,1]
}

# Save results
save(r.cort,se.cort,low.ci.cort,up.ci.cort,n.patients, file=paste0("EffectSizes_MDDvCTL_Epi_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_Epi_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 10. Regression number of episodes in MDD patients\n')}



# 11. Regression number of episodes in recurrent episode MDD patients
# ===================================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
r.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[(((merged_ordered$Recur==2) & !(is.na(merged_ordered$Epi))) & !(is.na(merged_ordered$Recur))),] 
attach(merged_ordered)

if(length(which(merged_ordered$Dx==1)) > 7){
cat('Running: 11. Regression number of episodes in recurrent episode MDD patients\n')

# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ Epi + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.patients[x-ncol(Covs)] = length(tmp$model[,2])

	partcor.i <- pcor.test(tmp$model[1],tmp$model[,2],tmp$model[,c(3:(ncol(tmp$model)-AgeSq_and_interactions))])	
	r.cort[x-ncol(Covs)]=partcor.i[,1]
}

# Save results
save(r.cort,se.cort,low.ci.cort,up.ci.cort,n.patients, file=paste0("EffectSizes_MDDvCTL_Epi_recur_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_Epi_recur_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 11. Regression number of episodes in recurrent episode MDD patients\n')}



# 12. Early-onset (<22) MDD vs controls
# =====================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[(((merged_ordered$AO<22) & !(is.na(merged_ordered$AO)))|(merged_ordered$Dx==0)),]
attach(merged_ordered)

if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 12. Early-onset (<22) MDD vs controls\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex", site, whole,")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_EAO21_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_EAO21_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 12. Early-onset (<22) MDD vs controls\n')}



# 13. Later-onset (>=22) MDD vs controls
# ======================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[(((merged_ordered$AO>=22) & !(is.na(merged_ordered$AO)))|(merged_ordered$Dx==0)),]
attach(merged_ordered)

if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 13. Later-onset (>=22) MDD vs controls\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_LAO21_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_LAO21_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 13. Later-onset (>=22) MDD vs controls\n')}



# 14. Early-onset (<22) MDD vs later-onset MDD (>=22)
# ===================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.EAO=rep(NA,N_of_tests)
n.LAO=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
AO21_groups<- merged_ordered$AO
AO21_groups[AO21_groups < 22] <- 1
AO21_groups[AO21_groups >= 22] <- 2
AO21_groups[merged_ordered$Dx == 0] <- 0

merged_ordered_AO21groups<- cbind(merged_ordered,AO21_groups)

merged_ordered <- merged_ordered_AO21groups[((merged_ordered_AO21groups$AO21_groups!=0) & !(is.na(merged_ordered_AO21groups$AO21_groups))),]
rm(AO21_groups)
attach(merged_ordered)

if((length(which(merged_ordered$AO21_groups==1)) > 7) & (length(which(merged_ordered$AO21_groups==2)) > 7)){
cat('Running: 14. Early-onset (<22) MDD vs later-onset MDD (>=22)\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin-1)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(AO21_groups) + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.EAO[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	n.LAO[x-ncol(Covs)] = length(which(tmp$model[,2] == 2))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.EAO[x-ncol(Covs)],n.LAO[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.EAO[x-ncol(Covs)],n.LAO[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.EAO,n.LAO, file=paste0("EffectSizes_MDDvCTL_EAOvLAO21_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_EAOvLAO21_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 14. Early-onset (<22) MDD vs later-onset MDD (>=22)\n')}



# 15. Regression HDRS severity in MDD patients
# ============================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
r.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[((merged_ordered$Dx==1) & !(is.na(merged_ordered$HDRS))),]
attach(merged_ordered)

if(length(which(merged_ordered$Dx==1)) > 7){
cat('Running: 15. Regression HDRS severity in MDD patients\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ HDRS + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.patients[x-ncol(Covs)] = length(tmp$model[,2])
	
	partcor.i <- pcor.test(tmp$model[1],tmp$model[,2],tmp$model[,c(3:(ncol(tmp$model)-AgeSq_and_interactions*2))])	
	r.cort[x-ncol(Covs)]=partcor.i[,1]
}

# Save results
save(r.cort,se.cort,low.ci.cort,up.ci.cort,n.patients, file=paste0("EffectSizes_MDDvCTL_HDRS_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_HDRS_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 15. Regression HDRS severity in MDD patients\n')}



# 16. Regression HDRS severity in first episode MDD patients
# ==========================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
r.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[(((merged_ordered$Recur==1) & !(is.na(merged_ordered$HDRS))) & !(is.na(merged_ordered$Recur))),]
attach(merged_ordered)

if(length(which(merged_ordered$Dx==1)) > 7){
cat('Running: 16. Regression HDRS severity in first episode MDD patients\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ HDRS + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.patients[x-ncol(Covs)] = length(tmp$model[,2])
	
	partcor.i <- pcor.test(tmp$model[1],tmp$model[,2],tmp$model[,c(3:(ncol(tmp$model)-AgeSq_and_interactions*2))])	
	r.cort[x-ncol(Covs)]=partcor.i[,1]
}

# Save results
save(r.cort,se.cort,low.ci.cort,up.ci.cort,n.patients, file=paste0("EffectSizes_MDDvCTL_HDRS_first_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_HDRS_first_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 16. Regression HDRS severity in first episode MDD patients\n')}



# 17. Regression HDRS severity in recurrent MDD patients
# ======================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
r.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[(((merged_ordered$Recur==2) & !(is.na(merged_ordered$HDRS))) & !(is.na(merged_ordered$Recur))),]
attach(merged_ordered)

if(length(which(merged_ordered$Dx==1)) > 7){
cat('Running: 17. Regression HDRS severity in recurrent MDD patients\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ HDRS + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.patients[x-ncol(Covs)] = length(tmp$model[,2])
	
	partcor.i <- pcor.test(tmp$model[1],tmp$model[,2],tmp$model[,c(3:(ncol(tmp$model)-AgeSq_and_interactions*2))])	
	r.cort[x-ncol(Covs)]=partcor.i[,1]
}

# Save results
save(r.cort,se.cort,low.ci.cort,up.ci.cort,n.patients, file=paste0("EffectSizes_MDDvCTL_HDRS_recur_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_HDRS_recur_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 17. Regression HDRS severity in recurrent MDD patients\n')}



# 18. Regression BDI severity in MDD patients
# ===========================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
r.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[((merged_ordered$Dx==1) & !(is.na(merged_ordered$BDI))),]
attach(merged_ordered)

if(length(which(merged_ordered$Dx==1)) > 7){
cat('Running: 18. Regression BDI severity in MDD patients\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ BDI + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.patients[x-ncol(Covs)] = length(tmp$model[,2])
	
	partcor.i <- pcor.test(tmp$model[1],tmp$model[,2],tmp$model[,c(3:(ncol(tmp$model)-AgeSq_and_interactions*2))])	
	r.cort[x-ncol(Covs)]=partcor.i[,1]
}

# Save results
save(r.cort,se.cort,low.ci.cort,up.ci.cort,n.patients, file=paste0("EffectSizes_MDDvCTL_BDI_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_BDI_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 18. Regression BDI severity in MDD patients\n')}



# 19. Regression BDI severity in first episode MDD patients
# =========================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
r.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[(((merged_ordered$Recur==1) & !(is.na(merged_ordered$BDI))) & !(is.na(merged_ordered$Recur))),]
attach(merged_ordered)

if(length(which(merged_ordered$Dx==1)) > 7){
cat('Running: 19. Regression BDI severity in first episode MDD patients\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ BDI + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.patients[x-ncol(Covs)] = length(tmp$model[,2])
	
	partcor.i <- pcor.test(tmp$model[1],tmp$model[,2],tmp$model[,c(3:(ncol(tmp$model)-AgeSq_and_interactions*2))])	
	r.cort[x-ncol(Covs)]=partcor.i[,1]
}

# Save results
save(r.cort,se.cort,low.ci.cort,up.ci.cort,n.patients, file=paste0("EffectSizes_MDDvCTL_BDI_first_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_BDI_first_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 19. Regression BDI severity in first episode MDD patients\n')}


# 20. Regression BDI severity in recurrent MDD patients
# =====================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
r.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered <- merged_ordered[(((merged_ordered$Recur==2) & !(is.na(merged_ordered$BDI))) & !(is.na(merged_ordered$Recur))),]
attach(merged_ordered)

if(length(which(merged_ordered$Dx==1)) > 7){
cat('Running: 20. Regression BDI severity in recurrent MDD patients\n')

# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ BDI + Age + Sex", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.patients[x-ncol(Covs)] = length(tmp$model[,2])
	
	partcor.i <- pcor.test(tmp$model[1],tmp$model[,2],tmp$model[,c(3:(ncol(tmp$model)-AgeSq_and_interactions*2))])	
	r.cort[x-ncol(Covs)]=partcor.i[,1]
}

# Save results
save(r.cort,se.cort,low.ci.cort,up.ci.cort,n.patients, file=paste0("EffectSizes_MDDvCTL_BDI_recur_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_BDI_recur_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 20. Regression BDI severity in recurrent MDD patients\n')}



# 21. Antidepressant users vs controls, controlling for recurrence 
# ================================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered_AD<- merged_ordered[((merged_ordered$AD!=1) & !(is.na(merged_ordered$AD)) & !(is.na(merged_ordered$Recur))),]
merged_ordered_AD$Recurnew <- ifelse(merged_ordered_AD$Recur==2,1,0)
merged_ordered=merged_ordered_AD
attach(merged_ordered)

if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 21. Antidepressant users vs controls, controlling for recurrence\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin-1)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex + Recurnew", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_AD_ctlRecur_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_AD_ctlRecur_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 21. Antidepressant users vs controls, controlling for recurrence\n')}



# 22. non-antidepressant users vs controls, controlled for recurrence
# ===================================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered_noAD<- merged_ordered[((merged_ordered$AD!=2) & !(is.na(merged_ordered$AD)) & !(is.na(merged_ordered$Recur))),]
merged_ordered_noAD$Recurnew <- ifelse(merged_ordered_noAD$Recur==2,1,0)
merged_ordered=merged_ordered_noAD
attach(merged_ordered)

if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 22. non-antidepressant users vs controls, controlled for recurrence\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin-1)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex + Recurnew", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_noAD_ctlRecur_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_noAD_ctlRecur_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 22. non-antidepressant users vs controls, controlled for recurrence\n')}



# 23. Antidepressant users vs non-antidepressant users, controlled for recurrence
# ===============================================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.noAD=rep(NA,N_of_tests)
n.AD=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered_ADnoAD <- merged_ordered[((merged_ordered$AD!=0) & !(is.na(merged_ordered$AD)) & !(is.na(merged_ordered$Recur))),]
merged_ordered_ADnoAD$Recurnew <- ifelse(merged_ordered_ADnoAD$Recur==2,1,0)
merged_ordered=merged_ordered_ADnoAD
attach(merged_ordered)

if((length(which(merged_ordered$AD==1)) > 7) & (length(which(merged_ordered$AD==2)) > 7)){
cat('Running: 23. Antidepressant users vs non-antidepressant users, controlled for recurrence\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin-1)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(AD) + Age + Sex + Recurnew", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.noAD[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	n.AD[x-ncol(Covs)] = length(which(tmp$model[,2] == 2))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.noAD[x-ncol(Covs)],n.AD[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.noAD[x-ncol(Covs)],n.AD[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.noAD,n.AD, file=paste0("EffectSizes_MDDvCTL_ADnoAD_ctlRecur_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_ADnoAD_ctlRecur_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 23. Antidepressant users vs non-antidepressant users, controlled for recurrence\n')}



# 24. Antidepressant users vs controls, controlling for EAO<21 
# ============================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered_AD_EAO<- merged_ordered[(((merged_ordered$AD!=1) & !(is.na(merged_ordered$AD)) & !(is.na(merged_ordered$AO))) | (merged_ordered$Dx==0)),]
merged_ordered_AD_EAO$EAO <- ifelse(merged_ordered_AD_EAO$AO>=22 | is.na(merged_ordered_AD_EAO$AO),0,1)
merged_ordered=merged_ordered_AD_EAO
attach(merged_ordered)

if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 24. Antidepressant users vs controls, controlling for EAO<21 \n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin-1)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex + EAO", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_AD_ctlEAO_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_AD_ctlEAO_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 24. Antidepressant users vs controls, controlling for EAO<21\n')}



# 25. non-antidepressant users vs controls, controlled for EAO<21
# ===============================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.controls=rep(NA,N_of_tests)
n.patients=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered_noAD_EAO<- merged_ordered[(((merged_ordered$AD!=2) & !(is.na(merged_ordered$AD)) & !(is.na(merged_ordered$AO))) | (merged_ordered$Dx==0)),]
merged_ordered_noAD_EAO$EAO <- ifelse(merged_ordered_noAD_EAO$AO>=22 | is.na(merged_ordered_noAD_EAO$AO),0,1)
merged_ordered=merged_ordered_noAD_EAO
attach(merged_ordered)

if((length(which(merged_ordered$Dx==1)) > 7) & (length(which(merged_ordered$Dx==0)) > 7)){
cat('Running: 25. non-antidepressant users vs controls, controlled for EAO<21\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin-1)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(Dx) + Age + Sex + EAO", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Subjects can be dropped if they are missing so we can get the precise number of controls/patients for each region tested
	n.controls[x-ncol(Covs)] = length(which(tmp$model[,2] == 0))
	n.patients[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.controls[x-ncol(Covs)],n.patients[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.controls,n.patients, file=paste0("EffectSizes_MDDvCTL_noAD_ctlEAO_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_noAD_ctlEAO_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 25. non-antidepressant users vs controls, controlled for EAO<21\n')}



# 26. Antidepressant users vs non-antidepressant users, controlled for EAO<21
# ===========================================================================

models.cort=NULL

# Allocate empty vectors to store adjust effect sizes, se, ci (noicv)
d.cort=rep(NA,N_of_tests)
se.cort=rep(NA,N_of_tests)
low.ci.cort=rep(NA,N_of_tests)
up.ci.cort=rep(NA,N_of_tests)
n.noAD=rep(NA,N_of_tests)
n.AD=rep(NA,N_of_tests)

# Attach main file
detach(merged_ordered)
merged_ordered=swap.merged_ordered
merged_ordered_ADnoAD_EAO <- merged_ordered[((merged_ordered$AD!=0) & !(is.na(merged_ordered$AD)) & !(is.na(merged_ordered$AO))),]
merged_ordered_ADnoAD_EAO$EAO <- ifelse(merged_ordered_ADnoAD_EAO$AO>=22 | is.na(merged_ordered_ADnoAD_EAO$AO),0,1)
merged_ordered=merged_ordered_ADnoAD_EAO
attach(merged_ordered)

if((length(which(merged_ordered$AD==1)) > 7) & (length(which(merged_ordered$AD==2)) > 7)){
cat('Running: 26. Antidepressant users vs non-antidepressant users, controlled for EAO<21\n')
	
# Loop through and perform each regression
for(x in (ncol(Covs)+1):(ncol(merged_ordered)-rightmargin-1)){
	pheno=merged_ordered[!is.na(merged_ordered[,x]),x] #Check to make sure there are observations for a given structure
	# Check if the phenotype is singular after NA removal
	if(length(pheno)==0){
		next; # Skip the whole structure if there are no observations
	}
	site=NULL # These are just string variables that modify the model in R if there are Site variables in the Covariates.csv file
	if(n.sites != 0){
		site=" + " #Starts the string to add-on Site variables
		for(i in 1:n.sites){
			if(i != n.sites){
				site=paste(site, "Site", i, " + ", sep='')
			}
			else{
				site=paste(site, "Site", i, sep='')
			}
		}
	}
	# Run the model
	test=merged_ordered[,x]
	eval(parse(text=paste("tmp=lm(test ~ factor(AD) + Age + Sex + EAO", site, whole, ")", sep='')))
	models.cort[[x-ncol(Covs)]]=tmp # Store the model fit for future reference
	
	# Precise number of controls/patients for each region tested
	n.noAD[x-ncol(Covs)] = length(which(tmp$model[,2] == 1))
	n.AD[x-ncol(Covs)] = length(which(tmp$model[,2] == 2))
	
	# Convert the lm model to a summary format so we can extract statistics
	tmp=summary(tmp)
	tstat=tmp$coefficients[2,3] # Get t-statistic from regression to convert to Cohens d
	tstat.df=tmp$df[2]
	
	# Collect effect size data
	d.cort[x-ncol(Covs)]=partial.d(tstat,tstat.df,n.noAD[x-ncol(Covs)],n.AD[x-ncol(Covs)])
	se.cort[x-ncol(Covs)]=se.d2(d.cort[x-ncol(Covs)],n.noAD[x-ncol(Covs)],n.AD[x-ncol(Covs)])
	bound.cort=CI1(d.cort[x-ncol(Covs)],se.cort[x-ncol(Covs)])
	low.ci.cort[x-ncol(Covs)]=bound.cort[1]
	up.ci.cort[x-ncol(Covs)]=bound.cort[2]
}

# Save results
save(d.cort,se.cort,low.ci.cort,up.ci.cort,n.noAD,n.AD, file=paste0("EffectSizes_MDDvCTL_ADnoAD_ctlEAO_",filetype,globvarname,".Rdata"))
save(models.cort, file=paste0("Models_MDDvCTL_ADnoAD_ctlEAO_",filetype,globvarname,".Rdata"))
} else {cat('NOT Running: 26. Antidepressant users vs non-antidepressant users, controlled for EAO<21\n')}


cat(paste0('Done working on ', fsfile,'.\n'))
if (write_logfile){sink()}
detach(merged_ordered)
if (write_logfile){print(readLines(paste0(name_logfile)))}
